@@ -1,13 +1,16 @@
-Boot <- function(rf, n){
+Boot <- function(rf, R){
+
+    cat("(3) Do bootstrapping ... ")
+
     G <- rf$Gij
     Gset <- data.frame(no = as.numeric(row.names(rf)), G = G)
     Gset_list <- split(Gset, Gset$no)
 
     boot <- function(l){
-        sample <- c(l$G, sample(x = G[G != l$G], n-1, replace = T))
+        sample <- c(l$G, sample(x = G[G != l$G], R-1, replace = T))
         sample[is.na(sample)] <- -100
         sorted <- sort(sample, decreasing = T)
-        cr <- which(sorted == sample[1])/n
+        cr <- which(sorted == sample[1])/R
         return(cr)
     }
 
@@ -15,5 +18,7 @@ Boot <- function(rf, n){
 
     result <- cbind(rf, pval)
 
+    cat("Done ! \n")
+
     return(result)
 }
